@@ -1,6 +1,6 @@
 package Date::Utils;
 
-$Date::Utils::VERSION   = '0.23';
+$Date::Utils::VERSION   = '0.24';
 $Date::Utils::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Date::Utils - Common date functions as Moo Role.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
@@ -19,7 +19,7 @@ use POSIX qw/floor/;
 use Term::ANSIColor::Markup;
 
 use Moo::Role;
-use namespace::clean;
+use namespace::autoclean;
 
 use Date::Exception::InvalidDay;
 use Date::Exception::InvalidMonth;
